Skip to contents

Combine multiple intData objects by rows.

Usage

rbind(..., deparse.level = 1)

# S4 method for class 'intData'
rbind(..., deparse.level = 1)

Arguments

...

intData objects to combine.

deparse.level

An integer controlling the construction of labels in the result (default is 1).

Value

An intData object with rows combined from the input intData objects.