Computes the angle error between eigenvalues of the estimated covariance matrix and of the ground truth covariance matrix.
Details
The angle error is given by: $$1-\dfrac{\hat{\boldsymbol{a}}^\top\boldsymbol{a}}{\sqrt{\hat{\boldsymbol{a}}^\top\hat{\boldsymbol{a}}}\sqrt{\boldsymbol{a}^\top\boldsymbol{a}}},$$ where \(\hat{\boldsymbol{a}}\) and \(\boldsymbol{a}\) are the eigenvalues of the estimated and ground truth covariance matrices, respectively.