Estimate farness from a distance vector in order to identify outlier observations.
Value
Either a vector of farness probabilities for each observation (if cutoff_value is not provided) or a list containing (if cutoff_value is provided):
farness_probsA vector of farness probabilities for each observation. Values between 0 and 1.
cutoff_valueThe cutoff distance value in the original distance scale corresponding to the specified
cutoff_valueprobability.
References
J. Raymaekers and P.J. Rousseeuw (2021). Transforming variables to central normality. Machine Learning. doi:10.1007/s10994-021-05960-5
Based on the cellWise package: Raymaekers J, Rousseeuw P (2023). cellWise: Analyzing Data with Cellwise Outliers. R package version 2.5.3, https://CRAN.R-project.org/package=cellWise.