A class to represent interval data.
Slots
CentersA data frame of centers of the intervals.
RangesA data frame of ranges of the intervals.
LatentParamA list with the parameters of the latent variables.
LatentCaseA string specifying which of the three scenarios applies to the latent variables:
"General": The case where the latent variables do not have any nice properties."U_id": The case where the latent variables are identically distributed."U_id_symmetric": The case where the latent variables are identically distributed and symmetric.
Defaults to
"U_id_symmetric".LatentDistA string or vector of strings specifying the distribution(s) of the latent variables. If the variables are identically distributed it can be one of (
"Unif","Triang","TNorm","InvTri","Beta","KDE","Degenerated"), if not, it is a vector with the distribution for each variable.ObsNamesA character vector of observation names.
VarNamesA character vector of variable names.
NObsA numeric value indicating the number of observations.
NIVarA numeric value indicating the number of interval variables.
NbMicroUnitsAn integer indicating the number of micro units.
References
Oliveira, M. R., Pinheiro, D., & Oliveira, L. (2025). Location and association measures for interval-valued data based on Mallows' distance. arXiv preprint arXiv:2407.05105. https://arxiv.org/abs/2407.05105
Adapted from package MAINT.Data (https://cran.r-project.org/package=MAINT.Data).