R/intData_class.r
rbind.Rd
Combine multiple intData objects by rows.
rbind(..., deparse.level = 1) # S4 method for class 'intData' rbind(..., deparse.level = 1)
intData objects to combine.
An integer controlling the construction of labels in the result (default is 1).
1
An intData object with rows combined from the input intData objects.